abacusai.api_class.dataset — AbacusAI documentation

# `abacusai.api_class.dataset`

## Module Contents

### Classes

`ParsingConfig` | Helper class that provides a standard way to create an ABC using
`DocumentProcessingConfig` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.dataset.ParsingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  escape: str
  csv_delimiter: str
  file_path_with_schema: str

class abacusai.api_class.dataset.DocumentProcessingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  extract_bounding_boxes: bool = False
  convert_to_markdown: bool = False
  remove_header_footer: bool = False
  use_doctr: bool = False
  remove_watermarks: bool
  use_full_ocr: bool